@@ -14,6 +14,14 @@ pub mod admin;
 #[cfg_attr(docsrs, doc(cfg(feature = "client")))]
 pub mod client;
 
+#[cfg(feature = "errors")]
+#[cfg_attr(docsrs, doc(cfg(feature = "errors")))]
+pub mod errors;
+
+#[cfg(feature = "initialized")]
+#[cfg_attr(docsrs, doc(cfg(feature = "initialized")))]
+pub mod initialized;
+
 #[cfg(feature = "log")]
 #[cfg_attr(docsrs, doc(cfg(feature = "log")))]
 pub mod log;
@@ -22,6 +30,10 @@ pub mod log;
 #[cfg_attr(docsrs, doc(cfg(feature = "requeue")))]
 pub mod requeue;
 
+#[cfg(feature = "runtime")]
+#[cfg_attr(docsrs, doc(cfg(feature = "runtime")))]
+pub mod runtime;
+
 #[cfg(feature = "server")]
 #[cfg_attr(docsrs, doc(cfg(feature = "server")))]
 pub mod server;
@@ -35,3 +47,15 @@ pub use self::admin::AdminArgs;
 
 #[cfg(all(feature = "client"))]
 pub use self::client::ClientArgs;
+
+#[cfg(all(feature = "initialized"))]
+pub use self::initialized::Initialized;
+
+#[cfg(all(feature = "log"))]
+pub use self::log::{LogFilter, LogFormat, LogInitError};
+
+#[cfg(all(feature = "runtime"))]
+pub use self::runtime::Runtime;
+
+#[cfg(all(feature = "server"))]
+pub use self::server::ServerArgs;
